#!/usr/sbin/perl

# Copyright Amit P. Singh, Douglas L. Brutlag, Stanford University.


$PDBPATH = "/db/pdb";
$DSSPPATH = "/db/dssp";
$DSSPPROGRAM = "/usr/local/bin/dssp";

#system commands used by this script:
#you may need to switch to full path names for some shells
$file = "file";
$cat = "cat";
$ln = "ln";
$gunzip = "gunzip";
$uncompress = "uncompress";
$rm = "rm";

#$file = "/usr/bin/file";
#$cat = "/bin/cat";
#$ln = "/bin/ln";
#$gunzip = "/usr/bin/gunzip";
#$uncompress = "/usr/bin/uncompress";
#$rm = "/bin/rm";

open STDOUT, ">/dev/null";
open STDERR, ">/dev/null";


select STDOUT; $| = 1;
select STDERR; $| = 1;

$longpdbname = shift(@ARGV);
$newname = shift(@ARGV);

if (-e $newname) {
    `$rm $newname`;
}

($pdbname) = $longpdbname =~ /^(....)/;

$pdbname =~ tr/A-Z/a-z/;

if ((not defined $pdbname) || (not defined $newname)) {
    exit(0);
}

$myfile = getFile("$DSSPPATH/$pdbname.dssp");

if ($myfile eq "NOFILE") {

    $newdsspfile = "$DSSPPATH/$pdbname.dssp";

    $tempfile = findFile($pdbname);

    if ($tempfile ne "NOFILE") {
	$tempfile = checkCompressed($tempfile);
	`$DSSPPROGRAM -na $tempfile $newdsspfile > /dev/null`;
	
	if (-e "/tmp/$$.temp") {
	    `$rm /tmp/$$.temp`;
	}

	if (-e $newdsspfile) {
	    `$ln -s $newdsspfile $newname`;
	}
	
    }

}

else {
    $temp = `$file $myfile`;

    @ftype = split /\s+/, $temp;

    if ($ftype[1] eq "gzip") {	
	`$cat $myfile | $gunzip > $newname`;
    }

    elsif (($ftype[1] eq "compressed") || ($ftype[1] eq "compress'd")) {	
	`$cat $myfile | $uncompress > $newname`;
    }
    else {
	`$ln -s $myfile $newname`;
    }
}

exit(0);
    
######################################################################

sub findFile() {

    ($two_letter) = $_[0] =~ /^[0-9](..)/;
    $mytemp = getFile("$PDBPATH/$two_letter/$_[0].pdb");
    if ($mytemp eq "NOFILE") {
	$mytemp = getFile("$PDBPATH/$_[0].pdb");
    }
    if ($mytemp eq "NOFILE") {
	$mytemp = getFile("$PDBPATH/pdb$_[0].ent");
    }
    
    return $mytemp;
}

sub getFile() {

    $mytemp = $_[0];

    if (-e $mytemp) {
	return $mytemp;
    }

    $mytemp = "$_[0]".".gz";
    if (-e $mytemp) {
	return $mytemp;
    }

    $mytemp = "$_[0]".".Z";
    if (-e $mytemp) {
	return $mytemp;
    }

    return "NOFILE";

}

    
sub checkCompressed() {

    $temp = `file $_[0]`;

    @ftype = split /\s+/, $temp;

    if ($ftype[1] eq "gzip") {	
	`$cat $_[0] | $gunzip > /tmp/$$.temp`;
	if (-e "/tmp/$$.temp") {
	    return "/tmp/$$.temp";
	}
	else {
	    return "NOFILE";
	}
    }

    if ($ftype[1] eq "compressed") {	
	`$cat $_[0] | $uncompress > /tmp/$$.temp`;
	if (-e "/tmp/$$.temp") {
	    return "/tmp/$$.temp";
	}
	else {
	    return "NOFILE";
	}
    }

    return $_[0];
}

